import tkinter as tk
import importlib.metadata
import os
from tkinter import ttk
from PIL import Image, ImageTk


class MainWindow(tk.Tk):
    def __init__(self):
        super().__init__()
        self.title("Main Window")

        self.popup_button = ttk.Button(
            self, text="Show Pop-up", command=self.show_popup
        )
        self.popup_button.pack(pady=20)

    def show_popup(self):
        popup = AboutWin(self)
        popup.show()


class AboutWin(tk.Toplevel):
    def __init__(self, master):
        super().__init__(master)
        self.title("Pop-up Window")
        self.geometry("300x200")  # Set the size of the pop-up window

        self.create_widgets()

    def create_widgets(self):
        # Load and display an image
        currdir = os.path.dirname(__file__)
        image_path = os.path.join(currdir, "about.png")  # Replace with your image path
        image = Image.open(image_path)
        photo = ImageTk.PhotoImage(image)
        image_label = tk.Label(self, image=photo)
        image_label.image = photo
        image_label.pack()

        # Add text
        version = importlib.metadata.version("xlfly")
        texts_to_show = f"xlfly - {version} \n Time to upgrade your tools"
        text_label = tk.Label(self, text=texts_to_show)
        text_label.pack(pady=10)

        # Button to close the pop-up
        close_button = ttk.Button(self, text="Close", command=self.destroy)
        close_button.pack(pady=10)

    def show(self):
        self.grab_set()  # Make the pop-up window modal
        self.wait_window()  # Wait for the pop-up window to be closed


if __name__ == "__main__":
    app = MainWindow()
    app.mainloop()



import pkg_resources
import subprocess
import sys


def check_requirements(rqm_txt):
    if rqm_txt is None:
        return

    requirements = rqm_txt.split(" ")

    requirements = [req.strip() for req in requirements]
    installed_packages = {pkg.key: pkg.version for pkg in pkg_resources.working_set}

    missing_packages = []
    for req in requirements:
        package_name = (
            req.split("==")[0].split(">=")[0].split("<=")[0].split("~=")[0].strip()
        )
        if package_name in installed_packages:
            try:
                pkg_resources.require(req)
                print(
                    f"{package_name} is installed and meets the version requirement: {req}"
                )
            except pkg_resources.VersionConflict as e:
                print(
                    f"{package_name} is installed but does not meet the version requirement: {req}"
                )
                print(f"Installed version: {installed_packages[package_name]}")
                missing_packages.append(req)
        else:
            print(f"{package_name} is not installed")
            missing_packages.append(req)

    return missing_packages


def install_packages(packages):
    if packages:
        print("\nInstalling missing packages...")
        subprocess.check_call([sys.executable, "-m", "pip", "install"] + packages)
    else:
        print("\nAll packages are already installed and meet the version requirements.")


def main():
    requirements_file = "requirements.txt"
    missing_packages = check_requirements(requirements_file)
    install_packages(missing_packages)


if __name__ == "__main__":
    main()



import tkinter as tk
import xlfly.app as xlapp
import xlwings as xw
import pandas as pd


root = tk.Tk()
app = xlapp.XlflyApp(root)

pre_cmd, local_var = app.cmd_condition()

for key, val in local_var.items():
    locals()[key] = val

exec(pre_cmd)

# put your debug command here, like
sht["A1"].value = 1



import os
import json

CONFIG_FILE = "xlfly.json"
# Define the path to the settings file in the user's personal folder
settings_file_path = os.path.join(os.path.expanduser("~"), CONFIG_FILE)


# Function to save settings to the file
def save_settings(settings):
    with open(settings_file_path, "w") as settings_file:
        json.dump(settings, settings_file, indent=4)


# Function to load settings from the file
def load_settings():
    if os.path.exists(settings_file_path):
        with open(settings_file_path, "r") as settings_file:
            return json.load(settings_file)
    return {}


if __name__ == "__main__":
    # Load settings at the start
    settings = load_settings()
    last_selected_folder = settings.get("last_selected_folder", "No folder selected")



import tkinter as tk
from tkinter import ttk
import os
from xlfly.configs import load_settings


class TempWindow:
    def __init__(self, parent):
        self.parent = parent
        settings = load_settings()
        tempfolder = settings["tempfolder"]

        subfolders = [
            name
            for name in os.listdir(tempfolder)
            if os.path.isdir(os.path.join(tempfolder, name))
        ]
        self.items = subfolders

        # Create the popup window
        self.popup_window = tk.Toplevel(parent)
        self.popup_window.title("Select Item")

        # Frame for filter entry, listbox, and buttons in popup
        self.frame = ttk.Frame(self.popup_window)
        self.frame.pack(padx=20, pady=20)

        # Filter Entry
        self.filter_entry = ttk.Entry(self.frame, width=30)
        self.filter_entry.pack(pady=10)
        self.filter_entry.bind("<KeyRelease>", self.update_listbox)

        # Listbox
        self.listbox = tk.Listbox(self.frame, selectmode=tk.SINGLE, width=30, height=5)
        self.listbox.pack(pady=10)

        # Populate listbox with initial items
        for item in self.items:
            self.listbox.insert(tk.END, item)

        # OK button
        self.ok_button = ttk.Button(self.frame, text="OK", command=self.on_ok)
        self.ok_button.pack(side=tk.LEFT, padx=10)

        # Cancel button
        self.cancel_button = ttk.Button(
            self.frame, text="Cancel", command=self.on_cancel
        )
        self.cancel_button.pack(side=tk.LEFT, padx=10)

        # Make the popup window modal
        self.popup_window.transient(parent)
        self.popup_window.grab_set()
        self.popup_window.wait_window()

    def update_listbox(self, event=None):
        filter_text = self.filter_entry.get().strip().lower()
        filtered_items = [item for item in self.items if filter_text in item.lower()]
        self.listbox.delete(0, tk.END)  # Clear previous items
        for item in filtered_items:
            self.listbox.insert(tk.END, item)

    def on_ok(self):
        selected_index = self.listbox.curselection()
        if selected_index:
            selected_item = self.listbox.get(selected_index[0])
        self.popup_window.destroy()
        self.selected_temp = selected_item

    def on_cancel(self):
        print("Selection canceled")
        self.selected_temp = None
        self.popup_window.destroy()


class MainWindow:
    def __init__(self, root):
        self.root = root
        self.root.title("Main Window")

        # Button to open popup window
        self.popup_button = ttk.Button(
            self.root, text="Open Popup", command=self.open_popup
        )
        self.popup_button.pack(padx=20, pady=20)

    def open_popup(self):
        popup = TempWindow(self.root)


if __name__ == "__main__":
    root = tk.Tk()
    app = MainWindow(root)
    root.mainloop()



"""
put addin xlam file to the directory
"""

import os
import shutil

# Get the path to the AddIns directory


def move_addin(xlam_file: str):
    "move xlam file to addin directory"

    destination_dir = os.path.join(os.getenv("APPDATA"), "Microsoft", "AddIns")

    # Copy the file
    try:
        shutil.copy(xlam_file, destination_dir)
        print(f"Copied {xlam_file} to {destination_dir}")
    except FileNotFoundError:
        print(f"The file {xlam_file} does not exist.")
    except PermissionError:
        print(f"Permission denied to copy the file to {destination_dir}.")
    except Exception as e:
        print(f"An error occurred: {e}")



import xlfly.create_shortcut
import os
import xlfly.configs as configs
import argparse


def main():
    parser = argparse.ArgumentParser(description="Run a Tkinter application.")
    parser.add_argument("--init", action="store_true", help="Create Start Menu")
    parser.add_argument("-t", "--tempfolder", type=str, help="Set Template Root Folder")
    args = parser.parse_args()

    if args.init:
        xlfly.create_shortcut.create_shortcut()

    if args.tempfolder:

        print(f"add {args.tempfolder} as template path")

        settings = configs.load_settings()
        folder_path = os.path.normpath(args.tempfolder)
        if folder_path:
            print(f"Selected folder: {folder_path}")
            settings["tempfolder"] = folder_path
            configs.save_settings(settings)


if __name__ == "__main__":
    main()
